pub struct StagePreparationStatus {Show 19 fields
pub topology_id: String,
pub run_id: String,
pub model_id: String,
pub backend: String,
pub package_ref: String,
pub manifest_sha256: String,
pub stage_id: String,
pub stage_index: u32,
pub layer_start: u32,
pub layer_end: u32,
pub state: i32,
pub bytes_done: Option<u64>,
pub bytes_total: Option<u64>,
pub bind_addr: Option<String>,
pub error: Option<String>,
pub shutdown_generation: u64,
pub coordinator_term: u64,
pub coordinator_id: Option<String>,
pub lease_until_unix_ms: u64,
}Fields
topology_id: Stringrun_id: Stringmodel_id: Stringbackend: Stringpackage_ref: Stringmanifest_sha256: Stringstage_id: Stringstage_index: u32layer_start: u32layer_end: u32state: i32bytes_done: Option<u64>bytes_total: Option<u64>bind_addr: Option<String>error: Option<String>shutdown_generation: u64coordinator_term: u64coordinator_id: Option<String>lease_until_unix_ms: u64Implementations
Sourceimpl StagePreparationStatus
impl StagePreparationStatus
Sourcepub fn state(&self) -> StagePreparationState
pub fn state(&self) -> StagePreparationState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: StagePreparationState)
pub fn set_state(&mut self, value: StagePreparationState)
Sets state to the provided enum value.
Sourcepub fn bytes_done(&self) -> u64
pub fn bytes_done(&self) -> u64
Returns the value of bytes_done, or the default value if bytes_done is unset.
Sourcepub fn bytes_total(&self) -> u64
pub fn bytes_total(&self) -> u64
Returns the value of bytes_total, or the default value if bytes_total is unset.
Sourcepub fn bind_addr(&self) -> &str
pub fn bind_addr(&self) -> &str
Returns the value of bind_addr, or the default value if bind_addr is unset.
Sourcepub fn error(&self) -> &str
pub fn error(&self) -> &str
Returns the value of error, or the default value if error is unset.
Sourcepub fn coordinator_id(&self) -> &str
pub fn coordinator_id(&self) -> &str
Returns the value of coordinator_id, or the default value if coordinator_id is unset.