pub struct StageStatus {Show 31 fields
pub topology_id: String,
pub run_id: String,
pub model_id: String,
pub backend: String,
pub stage_id: String,
pub stage_index: u32,
pub layer_start: u32,
pub layer_end: u32,
pub state: i32,
pub bind_addr: String,
pub activation_width: u32,
pub wire_dtype: i32,
pub error: Option<String>,
pub shutdown_generation: u64,
pub selected_device: Option<StageDevice>,
pub ctx_size: u32,
pub package_ref: Option<String>,
pub manifest_sha256: Option<String>,
pub source_model_path: Option<String>,
pub source_model_sha256: Option<String>,
pub source_model_bytes: Option<u64>,
pub materialized_path: Option<String>,
pub materialized_pinned: Option<bool>,
pub projector_path: Option<String>,
pub lane_count: u32,
pub n_batch: Option<u32>,
pub n_ubatch: Option<u32>,
pub flash_attn_type: i32,
pub coordinator_term: u64,
pub coordinator_id: Option<String>,
pub lease_until_unix_ms: u64,
}Fields
topology_id: Stringrun_id: Stringmodel_id: Stringbackend: Stringstage_id: Stringstage_index: u32layer_start: u32layer_end: u32state: i32bind_addr: Stringactivation_width: u32wire_dtype: i32error: Option<String>shutdown_generation: u64selected_device: Option<StageDevice>ctx_size: u32package_ref: Option<String>manifest_sha256: Option<String>source_model_path: Option<String>source_model_sha256: Option<String>source_model_bytes: Option<u64>materialized_path: Option<String>materialized_pinned: Option<bool>projector_path: Option<String>lane_count: u32n_batch: Option<u32>n_ubatch: Option<u32>flash_attn_type: i32coordinator_term: u64coordinator_id: Option<String>lease_until_unix_ms: u64Implementations
Sourceimpl StageStatus
impl StageStatus
Sourcepub fn state(&self) -> StageRuntimeState
pub fn state(&self) -> StageRuntimeState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: StageRuntimeState)
pub fn set_state(&mut self, value: StageRuntimeState)
Sets state to the provided enum value.
Sourcepub fn wire_dtype(&self) -> StageWireDType
pub fn wire_dtype(&self) -> StageWireDType
Returns the enum value of wire_dtype, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wire_dtype(&mut self, value: StageWireDType)
pub fn set_wire_dtype(&mut self, value: StageWireDType)
Sets wire_dtype to the provided enum value.
Sourcepub fn error(&self) -> &str
pub fn error(&self) -> &str
Returns the value of error, or the default value if error is unset.
Sourcepub fn package_ref(&self) -> &str
pub fn package_ref(&self) -> &str
Returns the value of package_ref, or the default value if package_ref is unset.
Sourcepub fn manifest_sha256(&self) -> &str
pub fn manifest_sha256(&self) -> &str
Returns the value of manifest_sha256, or the default value if manifest_sha256 is unset.
Sourcepub fn source_model_path(&self) -> &str
pub fn source_model_path(&self) -> &str
Returns the value of source_model_path, or the default value if source_model_path is unset.
Sourcepub fn source_model_sha256(&self) -> &str
pub fn source_model_sha256(&self) -> &str
Returns the value of source_model_sha256, or the default value if source_model_sha256 is unset.
Sourcepub fn source_model_bytes(&self) -> u64
pub fn source_model_bytes(&self) -> u64
Returns the value of source_model_bytes, or the default value if source_model_bytes is unset.
Sourcepub fn materialized_path(&self) -> &str
pub fn materialized_path(&self) -> &str
Returns the value of materialized_path, or the default value if materialized_path is unset.
Sourcepub fn materialized_pinned(&self) -> bool
pub fn materialized_pinned(&self) -> bool
Returns the value of materialized_pinned, or the default value if materialized_pinned is unset.
Sourcepub fn projector_path(&self) -> &str
pub fn projector_path(&self) -> &str
Returns the value of projector_path, or the default value if projector_path is unset.
Sourcepub fn n_batch(&self) -> u32
pub fn n_batch(&self) -> u32
Returns the value of n_batch, or the default value if n_batch is unset.
Sourcepub fn n_ubatch(&self) -> u32
pub fn n_ubatch(&self) -> u32
Returns the value of n_ubatch, or the default value if n_ubatch is unset.
Sourcepub fn flash_attn_type(&self) -> StageFlashAttnType
pub fn flash_attn_type(&self) -> StageFlashAttnType
Returns the enum value of flash_attn_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flash_attn_type(&mut self, value: StageFlashAttnType)
pub fn set_flash_attn_type(&mut self, value: StageFlashAttnType)
Sets flash_attn_type to the provided enum value.
Sourcepub fn coordinator_id(&self) -> &str
pub fn coordinator_id(&self) -> &str
Returns the value of coordinator_id, or the default value if coordinator_id is unset.