pub struct LoadStage {Show 35 fields
pub topology_id: String,
pub run_id: String,
pub model_id: String,
pub backend: String,
pub package_ref: String,
pub manifest_sha256: String,
pub stage_id: String,
pub stage_index: u32,
pub layer_start: u32,
pub layer_end: u32,
pub model_path: Option<String>,
pub selected_device: Option<StageDevice>,
pub bind_addr: String,
pub activation_width: u32,
pub wire_dtype: i32,
pub ctx_size: u32,
pub n_gpu_layers: i32,
pub cache_type_k: String,
pub cache_type_v: String,
pub shutdown_generation: u64,
pub load_mode: i32,
pub upstream: Option<StagePeer>,
pub downstream: Option<StagePeer>,
pub projector_path: Option<String>,
pub lane_count: u32,
pub n_batch: Option<u32>,
pub n_ubatch: Option<u32>,
pub flash_attn_type: i32,
pub source_model_bytes: Option<u64>,
pub coordinator_term: u64,
pub coordinator_id: Option<String>,
pub lease_until_unix_ms: u64,
pub native_mtp_enabled: Option<bool>,
pub mmap: Option<bool>,
pub mlock: Option<bool>,
}Fields
topology_id: Stringrun_id: Stringmodel_id: Stringbackend: Stringpackage_ref: Stringmanifest_sha256: Stringstage_id: Stringstage_index: u32layer_start: u32layer_end: u32model_path: Option<String>selected_device: Option<StageDevice>bind_addr: Stringactivation_width: u32wire_dtype: i32ctx_size: u32n_gpu_layers: i32cache_type_k: Stringcache_type_v: Stringshutdown_generation: u64load_mode: i32upstream: Option<StagePeer>downstream: Option<StagePeer>projector_path: Option<String>lane_count: u32n_batch: Option<u32>n_ubatch: Option<u32>flash_attn_type: i32source_model_bytes: Option<u64>coordinator_term: u64coordinator_id: Option<String>lease_until_unix_ms: u64native_mtp_enabled: Option<bool>mmap: Option<bool>mlock: Option<bool>Implementations
Sourceimpl LoadStage
impl LoadStage
Sourcepub fn model_path(&self) -> &str
pub fn model_path(&self) -> &str
Returns the value of model_path, or the default value if model_path is unset.
Sourcepub fn wire_dtype(&self) -> StageWireDType
pub fn wire_dtype(&self) -> StageWireDType
Returns the enum value of wire_dtype, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wire_dtype(&mut self, value: StageWireDType)
pub fn set_wire_dtype(&mut self, value: StageWireDType)
Sets wire_dtype to the provided enum value.
Sourcepub fn load_mode(&self) -> StageLoadMode
pub fn load_mode(&self) -> StageLoadMode
Returns the enum value of load_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_load_mode(&mut self, value: StageLoadMode)
pub fn set_load_mode(&mut self, value: StageLoadMode)
Sets load_mode to the provided enum value.
Sourcepub fn projector_path(&self) -> &str
pub fn projector_path(&self) -> &str
Returns the value of projector_path, or the default value if projector_path is unset.
Sourcepub fn n_batch(&self) -> u32
pub fn n_batch(&self) -> u32
Returns the value of n_batch, or the default value if n_batch is unset.
Sourcepub fn n_ubatch(&self) -> u32
pub fn n_ubatch(&self) -> u32
Returns the value of n_ubatch, or the default value if n_ubatch is unset.
Sourcepub fn flash_attn_type(&self) -> StageFlashAttnType
pub fn flash_attn_type(&self) -> StageFlashAttnType
Returns the enum value of flash_attn_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flash_attn_type(&mut self, value: StageFlashAttnType)
pub fn set_flash_attn_type(&mut self, value: StageFlashAttnType)
Sets flash_attn_type to the provided enum value.
Sourcepub fn source_model_bytes(&self) -> u64
pub fn source_model_bytes(&self) -> u64
Returns the value of source_model_bytes, or the default value if source_model_bytes is unset.
Sourcepub fn coordinator_id(&self) -> &str
pub fn coordinator_id(&self) -> &str
Returns the value of coordinator_id, or the default value if coordinator_id is unset.
Sourcepub fn native_mtp_enabled(&self) -> bool
pub fn native_mtp_enabled(&self) -> bool
Returns the value of native_mtp_enabled, or the default value if native_mtp_enabled is unset.